@@ -9,8 +9,8 @@ from trytond.i18n import gettext
 from trytond.model import ModelView, ModelSQL, fields
 from trytond.model.exceptions import AccessError
 from trytond.wizard import Wizard, StateView, StateTransition, Button
-from trytond.pyson import If, In, Eval, Bool
-from trytond.tools import sortable_values
+from trytond.pyson import If, Eval, Bool
+from trytond.tools import sortable_values, firstline
 from trytond.transaction import Transaction
 from trytond.pool import Pool
 
@@ -28,12 +28,22 @@ class PurchaseRequest(ModelSQL, ModelView):
     'Purchase Request'
     __name__ = 'purchase.request'
 
-    product = fields.Many2One('product.product', 'Product',
-        select=True, readonly=True, domain=[('purchasable', '=', True)])
+    product = fields.Many2One(
+        'product.product', "Product", select=True, readonly=True,
+        domain=[('purchasable', '=', True)],
+        context={
+            'company': Eval('company', -1),
+            },
+        depends=['company'])
     description = fields.Text('Description', readonly=True,
         states=STATES, depends=DEPENDS)
-    party = fields.Many2One('party.party', 'Party', select=True, states=STATES,
-        depends=DEPENDS)
+    summary = fields.Function(fields.Char('Summary'), 'on_change_with_summary')
+    party = fields.Many2One(
+        'party.party', "Party", select=True, states=STATES,
+        context={
+            'company': Eval('company', -1),
+            },
+        depends=DEPENDS + ['company'])
     quantity = fields.Float('Quantity', required=True, states=STATES,
         digits=(16, Eval('uom_digits', 2)), depends=DEPENDS + ['uom_digits'])
     uom = fields.Many2One('product.uom', 'UOM', select=True,
@@ -79,10 +89,7 @@ class PurchaseRequest(ModelSQL, ModelView):
     purchase = fields.Function(fields.Many2One('purchase.purchase',
         'Purchase'), 'get_purchase', searcher='search_purchase')
     company = fields.Many2One('company.company', 'Company', required=True,
-            readonly=True, domain=[
-                ('id', If(In('company', Eval('context', {})), '=', '!='),
-                    Eval('context', {}).get('company', -1)),
-            ])
+            readonly=True)
     origin = fields.Reference('Origin', selection='get_origin', readonly=True)
     exception_ignored = fields.Boolean('Ignored Exception')
 
@@ -177,9 +184,9 @@ class PurchaseRequest(ModelSQL, ModelView):
         Lang = pool.get('ir.lang')
         if self.product:
             lang = Lang.get()
-            rec_name = (lang.format(
-                    '%.*f', (self.uom.digits, self.quantity))
-                + '%s %s' % (self.uom.symbol, self.product.name))
+            rec_name = (lang.format_number_symbol(
+                    self.quantity, self.uom, digits=self.uom.digits)
+                + ' %s' % self.product.name)
         elif self.description:
             rec_name = self.description.splitlines()[0]
         else:
@@ -281,6 +288,10 @@ class PurchaseRequest(ModelSQL, ModelView):
             return self.product.default_uom.digits
         return 2
 
+    @fields.depends('description')
+    def on_change_with_summary(self, name=None):
+        return firstline(self.description or '')
+
     @classmethod
     def _get_origin(cls):
         'Return the set of Model names for origin Reference'
@@ -290,24 +301,22 @@ class PurchaseRequest(ModelSQL, ModelView):
     def get_origin(cls):
         pool = Pool()
         IrModel = pool.get('ir.model')
-        models = IrModel.search([
-                ('model', 'in', list(cls._get_origin())),
-                ])
-        return [(None, '')] + [(m.model, m.name) for m in models]
+        get_name = IrModel.get_name
+        models = cls._get_origin()
+        return [(None, '')] + [(m, get_name(m)) for m in models]
 
     @classmethod
     def view_attributes(cls):
-        return [
+        return super().view_attributes() + [
             ('/tree', 'visual', If(Eval('state') == 'cancelled', 'muted', '')),
             ]
 
     @classmethod
     def create(cls, vlist):
-        for vals in vlist:
-            for field_name in ('quantity', 'company'):
-                if vals.get(field_name) is None:
-                    raise AccessError(
-                        gettext('purchase_request.msg_request_no_create'))
+        transaction = Transaction()
+        if transaction.user != 0 and transaction.context.get('_check_access'):
+            raise AccessError(
+                gettext('purchase_request.msg_request_no_create'))
         return super(PurchaseRequest, cls).create(vlist)
 
     @classmethod
